import { ILogger } from 'pargv';
export declare type BeforeRender = {
    (template?: ITemplate, done?: {
        ();
    });
};
export declare type AfterRender = {
    (template?: ITemplate);
};
export declare type NodeCallback = {
    (err?: any, data?: any);
};
export declare type InjectCallback = {
    (line: string, data: string, done: {
        (line: string, data: string);
    });
};
export interface IMetadataComponent {
    name?: string;
    fullname?: string;
    group?: string;
    ext?: string;
    path?: string;
    from?: string;
}
export interface IMetadata {
    $component?: IMetadataComponent;
    [key: string]: any;
}
export interface IPartials {
    [key: string]: string | ITemplate;
}
export interface IConfig {
    name?: string;
    ext?: string;
    type?: string;
    appendType?: boolean;
    casing?: 'lower' | 'upper' | 'camel' | 'title' | 'capitalize';
    filenameCasing?: 'lower' | 'upper' | 'camel' | 'title' | 'capitalize';
    injects?: any[];
    rename?: string;
    outputDir?: string;
    beforeRender?: BeforeRender;
    afterRender?: AfterRender;
    partials?: string | string[] | IPartials;
    metadata?: IMetadata;
    noOutput?: boolean;
}
export interface ITemplate extends IConfig {
    absolute?: boolean;
    path?: string;
    pathNormalized?: string;
    body?: string;
    outputPath?: string;
    outputRelative?: string;
    raw?: string;
    rendered?: string;
    isPartial?: boolean;
    group?: string;
}
export interface ITemplates {
    [key: string]: ITemplate;
}
export interface IComponent {
    name?: string;
    templates: string[];
    series: boolean;
}
export interface IComponents {
    [key: string]: IComponent;
}
export interface IGroupOptions extends IComponent {
    series: boolean;
}
export interface IRegisterConfig extends IConfig {
    template?: string;
}
export interface IRegister {
    partials(...args: any[]): IRegister;
    partials(partials: string | string[] | IPartials): IRegister;
    beforeRender(beforeRender: BeforeRender): IRegister;
    afterRender(afterRender: AfterRender): IRegister;
}
export interface IInject {
    filename: string;
    find: string | RegExp;
    insert: string | string[];
    strategy: 'before' | 'after' | 'first' | 'last' | 'replace';
    done: NodeCallback;
    relative: boolean;
}
export interface IMustrOptions {
    configDir?: string;
    outputDir?: string;
    templateExt?: string;
    autoRegister?: boolean;
}
export interface IMustr {
    cwd: string;
    log: ILogger;
    registerPath: string;
    templatesPath: string;
    outputPath: string;
    templatesGlob: string[];
    templates: ITemplates;
    components: IComponents;
    options: IMustrOptions;
    init(force?: boolean): void;
    load(): IMustr;
    register(options: IRegisterConfig): IRegister;
    register(name: string | IRegisterConfig, template?: string | IRegisterConfig, options?: IRegisterConfig): IRegister;
    registerGroup(name: string, series: boolean): any;
    registerGroup(name: string, ...args: string[]): void;
    configure(name: string, options: IRegisterConfig): ITemplate;
    configure(name: string, output: string, group: string): any;
    configure(name: string, output?: string | IRegisterConfig, options?: IRegisterConfig | string): ITemplate;
    render(template: ITemplate, done?: NodeCallback): void;
    render(template: ITemplate, force?: boolean, done?: NodeCallback): void;
    render(template: ITemplate, options?: IRegisterConfig, done?: NodeCallback): void;
    render(template: ITemplate, options?: IRegisterConfig, force?: boolean, done?: NodeCallback): void;
    render(name: string | ITemplate, output?: string | IRegisterConfig | NodeCallback | boolean, options?: IRegisterConfig | NodeCallback | boolean, force?: boolean | NodeCallback, done?: NodeCallback, group?: string): void;
    inject(options: IInject, done?: NodeCallback): void;
    inject(filename: string | IInject, find: string | RegExp | NodeCallback, insert: string | string[], strategy: 'before' | 'after' | 'first' | 'last' | 'replace', done?: NodeCallback): void;
    transformCase(str: string, to: string): string;
}
